@@ -1,7 +1,7 @@
 /*
  * Calcurse - text-based organizer
  *
- * Copyright (c) 2004-2011 calcurse Development Team <misc@calcurse.org>
+ * Copyright (c) 2004-2012 calcurse Development Team <misc@calcurse.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,22 +38,23 @@
 typedef struct llist_item llist_item_t;
 struct llist_item {
   struct llist_item *next;
-  void              *data;
+  void *data;
 };
 
 typedef struct llist llist_t;
 struct llist {
   struct llist_item *head;
+  struct llist_item *tail;
 };
 
 typedef int (*llist_fn_cmp_t) (void *, void *);
-typedef int (*llist_fn_match_t) (void *, long);
+typedef int (*llist_fn_match_t) (void *, void *);
 typedef void (*llist_fn_free_t) (void *);
 
 /* Initialization and deallocation. */
-void          llist_init (llist_t *);
-void          llist_free (llist_t *);
-void          llist_free_inner (llist_t *, llist_fn_free_t);
+void llist_init(llist_t *);
+void llist_free(llist_t *);
+void llist_free_inner(llist_t *, llist_fn_free_t);
 
 #define LLIST_INIT(l) llist_init(l)
 #define LLIST_FREE(l) llist_free(l)
@@ -61,16 +62,19 @@ void          llist_free_inner (llist_t *, llist_fn_free_t);
   llist_free_inner(l, (llist_fn_free_t)fn_free)
 
 /* Retrieving list items. */
-llist_item_t *llist_first (llist_t *);
-llist_item_t *llist_nth (llist_t *, int);
-llist_item_t *llist_next (llist_item_t *);
-llist_item_t *llist_find_first (llist_t *, long, llist_fn_match_t);
-llist_item_t *llist_find_next (llist_item_t *, long, llist_fn_match_t);
-llist_item_t *llist_find_nth (llist_t *, int, long, llist_fn_match_t);
+llist_item_t *llist_first(llist_t *);
+llist_item_t *llist_nth(llist_t *, int);
+llist_item_t *llist_next(llist_item_t *);
+llist_item_t *llist_next_filter(llist_item_t *, void *, llist_fn_match_t);
+llist_item_t *llist_find_first(llist_t *, void *, llist_fn_match_t);
+llist_item_t *llist_find_next(llist_item_t *, void *, llist_fn_match_t);
+llist_item_t *llist_find_nth(llist_t *, int, void *, llist_fn_match_t);
 
 #define LLIST_FIRST(l) llist_first(l)
 #define LLIST_NTH(l, n) llist_nth(l, n)
 #define LLIST_NEXT(i) llist_next(i)
+#define LLIST_NEXT_FILTER(i, data, fn_match)                                  \
+  llist_next_filter(i, data, (llist_fn_match_t)fn_match)
 #define LLIST_FIND_FIRST(l, data, fn_match)                                   \
   llist_find_first(l, data, (llist_fn_match_t)fn_match)
 #define LLIST_FIND_NEXT(i, data, fn_match)                                    \
@@ -82,16 +86,19 @@ llist_item_t *llist_find_nth (llist_t *, int, long, llist_fn_match_t);
 #define LLIST_FIND_FOREACH(l, data, fn_match, i)                              \
   for (i = LLIST_FIND_FIRST (l, data, fn_match); i;                           \
        i = LLIST_FIND_NEXT (i, data, fn_match))
+#define LLIST_FIND_FOREACH_CONT(l, data, fn_match, i)                         \
+  for (i = LLIST_FIND_FIRST (l, data, fn_match); i;                           \
+       i = LLIST_NEXT_FILTER (i, data, fn_match))
 
 /* Accessing list item data. */
-void         *llist_get_data (llist_item_t *);
+void *llist_get_data(llist_item_t *);
 
 #define LLIST_GET_DATA(i) llist_get_data(i)
 
 /* List manipulation. */
-void          llist_add (llist_t *, void *);
-void          llist_add_sorted (llist_t *, void *, llist_fn_cmp_t);
-void          llist_remove (llist_t *, llist_item_t *);
+void llist_add(llist_t *, void *);
+void llist_add_sorted(llist_t *, void *, llist_fn_cmp_t);
+void llist_remove(llist_t *, llist_item_t *);
 
 #define LLIST_ADD(l, data) llist_add(l, data)
 #define LLIST_ADD_SORTED(l, data, fn_cmp)                                     \
